==> wcag-validation-1.23.31-sources.jar: org/verapdf/gf/model/impl/sa/tables/GFSATableBorderCell.java <==
/**
 * This file is part of veraPDF WCAG Validation, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF WCAG Validation is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF WCAG Validation as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF WCAG Validation as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.gf.model.impl.sa.tables;

import org.verapdf.model.GenericModelObject;
import org.verapdf.model.salayer.SATableBorderCell;
import org.verapdf.wcag.algorithms.entities.tables.tableBorders.TableBorderCell;

/**
 * @author Maxim Plushchov
 */
public class GFSATableBorderCell extends GenericModelObject implements SATableBorderCell {

	public static final String TABLE_BORDER_CELL_ELEMENT_TYPE = "SATableBorderCell";

	private TableBorderCell cell;

	public GFSATableBorderCell(TableBorderCell cell) {
		super(TABLE_BORDER_CELL_ELEMENT_TYPE);
		this.cell = cell;
	}

	@Override
	public Long getcolSpan() {
		return (long)cell.getColSpan();
	}

	@Override
	public Long getrowSpan() {
		return (long)cell.getRowSpan();
	}

	@Override
	public String getContext() {
		return cell.getBoundingBox().getLocation();
	}

	@Override
	public String getstructureID() {
		if (cell.getId() != null) {
			return "id:" + cell.getId();
		}
		return null;
	}

}

==> wcag-validation-1.23.51-sources.jar: org/verapdf/gf/model/impl/sa/tables/GFSATableBorderCell.java <==
/**
 * This file is part of veraPDF WCAG Validation, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF WCAG Validation is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF WCAG Validation as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF WCAG Validation as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.gf.model.impl.sa.tables;

import org.verapdf.gf.model.impl.sa.GFSAObject;
import org.verapdf.model.salayer.SATableBorderCell;
import org.verapdf.wcag.algorithms.entities.tables.tableBorders.TableBorderCell;

/**
 * @author Maxim Plushchov
 */
public class GFSATableBorderCell extends GFSAObject implements SATableBorderCell {

	public static final String TABLE_BORDER_CELL_ELEMENT_TYPE = "SATableBorderCell";

	private TableBorderCell cell;

	public GFSATableBorderCell(TableBorderCell cell) {
		super(TABLE_BORDER_CELL_ELEMENT_TYPE);
		this.cell = cell;
	}

	@Override
	public Long getcolSpan() {
		return (long)cell.getColSpan();
	}

	@Override
	public Long getrowSpan() {
		return (long)cell.getRowSpan();
	}

	@Override
	public String getContext() {
		return cell.getBoundingBox().getLocation();
	}

	@Override
	public String getstructureID() {
		if (cell.getId() != null) {
			return "id:" + cell.getId();
		}
		return null;
	}

}
